#
# spec file for package openscap-report
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           openscap-report
Version:        0.2.5
Release:        1.1
Summary:        A tool for generating human-readable reports from (SCAP) XCCDF and ARF results
# The entire source code is LGPL-2.1+ and GPL-2.0+ and MIT except schemas/ and assets/, which are Public Domain
License:        GPL-2.0-or-later AND LGPL-2.1-or-later AND MIT AND SUSE-Public-Domain
URL:            https://github.com/OpenSCAP/%{name}
Source0:        https://github.com/OpenSCAP/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
BuildRequires:  python3-devel
BuildRequires:  python3-lxml
BuildRequires:  python3-setuptools
BuildRequires:  python3-sphinx_rtd_theme
Requires:       python3-Jinja2
Requires:       python3-lxml
Provides:       bundled(patternfly) = 4
BuildArch:      noarch

%description
This package provides a command-line tool for generating
human-readable reports from SCAP XCCDF and ARF results.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
python3 setup.py build
sphinx-build -b man docs _build_docs

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
install -m 0644 -Dt %{buildroot}%{_mandir}/man1 _build_docs/oscap-report.1

# not sure how to do that:
#check
#tox

%files
%{_mandir}/man1/oscap-report.*
%{_bindir}/oscap-report
%exclude %{python3_sitelib}/tests/
%{python3_sitelib}/openscap_report/
%{python3_sitelib}/openscap_report-%{version}-py%{python3_bin_suffix}.egg-info/
%license LICENSE

%changelog
* Thu Sep 21 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 0.2.5:
  * Explain the calculation of the score
  * Fix deprecation warning
  * Fix empty Value property value
  * Rework the OVAL test details
  * Resolve references to OVAL endpoints
- includes changes from 0.2.4:
  * Show references and identifier as plain text when href is unavailable
  * Implement clear button for search bar
  * Explain OVAL and CPE AL operators
  * Various output updates
- includes changes from 0.2.3:
  * Add support for the check-fact-ref element in CPE-AL
  * Explanation of the result mapping between XCCDF and OVAL
  * Add multi-check rules
  * Change loading of OVAL result reports
  * Discover upstream in tmt
* Thu Jun 15 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix building against other python versions than 3.10.
* Tue Apr 11 2023 Marcus Meissner <meissner@suse.com>
- initial import 0.2.2
